#
# Copyright (c) 2008-2015 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'

from datetime import datetime

from zope.container.ordered import OrderedContainer
from zope.location import locate
from zope.location.interfaces import ISublocations
from zope.traversing.interfaces import ITraversable

from pyams_catalog.utils import index_object
from pyams_content.features.alert.interfaces import ALERT_CONTAINER_KEY, IAlertContainer, IAlertItem, IAlertTarget
from pyams_utils.adapter import ContextAdapter, adapter_config, get_annotation_adapter
from pyams_utils.factory import factory_config
from pyams_utils.timezone import tztime


@factory_config(IAlertContainer)
class AlertContainer(OrderedContainer):
    """Alert container persistent class"""

    last_id = 1

    def append(self, value, notify=True):
        key = str(self.last_id)
        if not notify:
            # pre-locate alert item to avoid multiple notifications
            locate(value, self, key)
        self[key] = value
        self.last_id += 1
        if not notify:
            # make sure that alert item is correctly indexed
            index_object(value)

    def get_visible_items(self):
        now = tztime(datetime.utcnow())
        for alert in filter(lambda x: IAlertItem(x).visible, self.values()):
            if alert.start_date and (alert.start_date > now):
                continue
            if alert.end_date and (alert.end_date < now):
                continue
            yield alert


@adapter_config(context=IAlertTarget, provides=IAlertContainer)
def alert_container_factory(target):
    """Alert container factory"""
    return get_annotation_adapter(target, ALERT_CONTAINER_KEY, IAlertContainer, name='++alert++')


@adapter_config(name='alert', context=IAlertTarget, provides=ITraversable)
class AlertContainerNamespace(ContextAdapter):
    """Alert container ++alert++ namespace"""

    def traverse(self, name, furtherpath=None):
        return IAlertContainer(self.context)


@adapter_config(name='alerts', context=IAlertTarget, provides=ISublocations)
class AlertContainerSublocations(ContextAdapter):
    """Alert container sub-locations adapter"""

    def sublocations(self):
        return IAlertContainer(self.context).values()
