#
# Copyright (c) 2015-2022 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

"""PyAMS_*** module

"""

__docformat__ = 'restructuredtext'

import datetime

from pyams_content.interfaces import MANAGE_CONTENT_PERMISSION
from pyams_content.shared.calendar import IWfCalendarEvent
from pyams_content.shared.common.zmi.workflow import PublicationRequestForm
from pyams_form.form import AJAXAddForm, ajax_config
from pyams_pagelet.pagelet import pagelet_config
from pyams_skin.layer import IPyAMSLayer
from pyams_utils.timezone import tztime


@pagelet_config(name='wf-propose.html',
                context=IWfCalendarEvent, layer=IPyAMSLayer,
                permission=MANAGE_CONTENT_PERMISSION)
@ajax_config(name='wf_propose.json',
             context=IWfCalendarEvent, layer=IPyAMSLayer,
             permission=MANAGE_CONTENT_PERMISSION, base=AJAXAddForm)
class CalendarEventPublicationRequestForm(PublicationRequestForm):
    """calendar event publication request form"""

    def updateWidgets(self, prefix=None):
        super().updateWidgets(prefix)
        expiration_date = self.widgets.get('publication_expiration_date')
        if expiration_date is not None:
            if self.context.end_date:
                date = self.context.end_date + datetime.timedelta(hours=1)
                expiration_date.value = tztime(date).strftime('%d/%m/%y %H:%M')
            else:
                date = self.context.start_date + datetime.timedelta(days=1)
                expiration_date.value = tztime(date).strftime('%d/%m/%y 00:00')
